---
name: New feature
about: Suggest a new feature.
title: ""
labels: "Type: ★ Enhancement"
---

## Prework

- [ ] Read and abide by the **gt-extras** [code of conduct](https://www.contributor-covenant.org/version/2/1/code_of_conduct/) and [contributing guidelines](https://github.com/posit-dev/gt_extras/blob/main/.github/CONTRIBUTING.md).
- [ ] Search for duplicates among the [existing issues](https://github.com/posit-dev/gt_extras/issues) (both open and closed).

## Proposal

Describe the new feature clearly and concisely. If applicable, write a minimal example in Python or in pseudo-code to show input, usage, and desired output.

To help us read any code you include (optional) please try to follow the [Style Guide for Python Code](https://peps.python.org/pep-0008/).
